async function getBody(c) {
  const contentType = c.req.header("Content-Type");
  if (contentType?.includes("application/x-www-form-urlencoded") || contentType?.includes("multipart/form-data")) {
    try {
      const body2 = transformFormData(
        await c.req.parseBody({
          dot: true,
          all: true
        })
      );
      return body2;
    } catch {
      return {};
    }
  }
  const body = await c.req.text();
  try {
    return JSON.parse(body);
  } catch {
  }
  return body;
}
function transformFormData(formData) {
  const body = {};
  for (const [key, value] of Object.entries(formData)) {
    if (typeof value === "string") {
      body[key] = value;
      continue;
    }
    if (isFile(value)) {
      body[key] = {
        name: value?.name,
        sizeInBytes: value?.size,
        type: value?.type,
        // Get date time string from unix timestamp
        lastModified: value.lastModified ? new Date(value.lastModified).toISOString() : void 0
      };
      continue;
    }
    if (Array.isArray(value)) {
      body[key] = value.map((item) => {
        if (typeof item !== "string" && isFile(item)) {
          return {
            name: item?.name,
            sizeInBytes: item?.size,
            type: item?.type,
            // Get date time string from unix timestamp
            lastModified: item.lastModified ? new Date(item.lastModified).toISOString() : void 0
          };
        }
        return value;
      });
      continue;
    }
    if (typeof value === "object") {
      body[key] = transformFormData(value);
      continue;
    }
  }
  return body;
}
function isFile(data) {
  return data instanceof File;
}
export {
  getBody
};
//# sourceMappingURL=getBody.js.map
